@@ -6,8 +6,8 @@ class NetworkError(Exception):
 class TCPServerOccupiedError(NetworkError):
     def __init__(self, server_name):
         super().__init__(
-            f"{server_name} has been occupied Note:TCP Server Currently \
-Only Support A Single Client")
+            "%s has been occupied Note:TCP Server Currently \
+Only Support A Single Client" % str(server_name))
 
 
 class CommParserError(NetworkError):
@@ -24,22 +24,22 @@ class CommNotConnectError(NetworkError):
 
 class InvaildPlugin(CommResourceError):
     def __init__(self, module: str, plugin: str):
-        super().__init__(f"Can not find plugin({module}.{plugin}).")
+        super().__init__("Can not find plugin(%s.%s)." % (str(module), str(plugin)))
 
 
 class InvaildModule(CommResourceError):
     def __init__(self, module: str):
-        super().__init__(f"Can not find module({module}).")
+        super().__init__("Can not find module(%s)." % str(module))
 
 
 class InvaildMethod(CommParserError):
     def __init__(self, method: str):
-        super().__init__(f"Can not parser method({method}).")
+        super().__init__("Can not parser method(%s)." % str(method))
 
 
 class InvaildJsonMsg(CommParserError):
     def __init__(self, e: Exception):
-        super().__init__(f"Message can not convert to json object: {e}.")
+        super().__init__("Message can not convert to json object: %s." % str(e))
 
 
 class RpcIdInvaild(CommParserError):
