@@ -18,7 +18,7 @@ import asyncio
 from websockets import WebSocketServerProtocol
 from .Utils import loggers
 from .Message import message_center as mc
-from typing import Any, NoReturn
+from typing import Any
 from . import NetworkError
 
 LOGGER_NAME = "RPCServer"
@@ -39,7 +39,7 @@ class RPCServer(object):
 
         self.__on_disconnected = on_disconnected
         self.__on_connected = on_connected
-        self.__loop: asyncio.BaseEventLoop = loop
+        self.__loop = loop
         self.__server_name = "DobotRPC-WSServer"
 
         self.__ban_list = (
@@ -89,30 +89,32 @@ class RPCServer(object):
         except Exception as e:
             feedback = self.__pack_rpc(rpc_id, e)
 
-        address = f"{websocket.host}:{websocket.port}"
-        remote_address = f"{websocket.remote_address[0]}:\
-{websocket.remote_address[1]}"
+        address = "%s:%s" % (str(websocket.host), str(websocket.port))
+        remote_address = "%s:%s" % (
+            str(websocket.remote_address[0]), str(websocket.remote_address[1]))
 
         loggers.get(LOGGER_NAME).debug(
-            f"S({address}) >> C({remote_address}): {feedback}")
+            "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(feedback)))
         await websocket.send(feedback)
 
     async def __on_new_onnection(self, websocket: WebSocketServerProtocol,
-                                 _) -> NoReturn:
-        ip, port = websocket.remote_address
-        address = f"{websocket.host}:{websocket.port}"
-        remote_address = f"{ip}:{port}"
+                                 _):
+        ip = websocket.remote_address[0]
+        port = websocket.remote_address[1]
+        address = "%s:%s" % (str(websocket.host), str(websocket.port))
+        remote_address = "%s:%s" % (str(ip), str(port))
 
         if ip in self.__ban_list:
-            loggers.get(LOGGER_NAME).warning(f"{ip} had been baned.")
+            loggers.get(LOGGER_NAME).warning("%s had been baned." % str(ip))
             send_str = "You had been baned."
 
             loggers.get(LOGGER_NAME).debug(
-                f"S({address}) >> C({remote_address}): {send_str}")
+                "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(send_str)))
             await websocket.send(send_str)
             return
 
-        loggers.get(LOGGER_NAME).info(f"Client({ip}:{port}) connected.")
+        loggers.get(LOGGER_NAME).info(
+            "Client(%s:%s) connected." % (str(ip), str(port)))
         self.__ws_clients.add(websocket)
 
         if self.__on_connected:
@@ -124,7 +126,7 @@ class RPCServer(object):
             try:
                 message = await websocket.recv()
                 loggers.get(LOGGER_NAME).debug(
-                    f"S({address}) << C({remote_address}): {message}")
+                    "S(%s) << C(%s): %s" % (str(address), str(remote_address), str(message)))
             except Exception as e:
                 loggers.get(LOGGER_NAME).error(e, exc_info=True)
                 break
@@ -144,12 +146,12 @@ class RPCServer(object):
             except Exception as e:
                 loggers.get(LOGGER_NAME).error(e, exc_info=True)
                 loggers.get(LOGGER_NAME).debug(
-                    f"S({address}) >> C({remote_address}): {e}")
+                    "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(e)))
                 await websocket.send(str(e))
                 continue
 
         loggers.get(LOGGER_NAME).warning(
-            f"{ip}:{port} had disconnected!!!!!!!!")
+            "%s:%s had disconnected!!!!!!!!" % (str(ip), str(port)))
         self.__ws_clients.remove(websocket)
 
         if self.__on_disconnected:
@@ -197,7 +199,8 @@ class RPCServer(object):
                 if "code" in error_str:
                     rpc_playload = demjson.decode(error_str)
                 else:
-                    rpc_playload = {"code": -32000, "message": f"{error_str}"}
+                    rpc_playload = {"code": -32000,
+                                    "message": "%s" % error_str}
                 loggers.get(LOGGER_NAME).error(rpc_playload, exc_info=True)
                 data["error"] = rpc_playload
             else:
@@ -242,11 +245,11 @@ class RPCServer(object):
         rpc_packet = self.__pack_rpc(None, data, method)
         tasks = []
         for websocket in self.__ws_clients:
-            address = f"{websocket.host}:{websocket.port}"
-            remote_address = f"{websocket.remote_address[0]}:\
-{websocket.remote_address[1]}"
+            address = "%s:%s" % (str(websocket.host), str(websocket.port))
+            remote_address = "%s:%s" % (
+                str(websocket.remote_address[0]), str(websocket.remote_address[1]))
             loggers.get(LOGGER_NAME).debug(
-                f"S({address}) >> C({remote_address}): {rpc_packet}")
+                "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(feedback)))
             tasks.append(websocket.send(rpc_packet))
         await asyncio.wait(tasks)
 
